<?php

/**
 * Get number of users per email domain
 *
 * @return array
 */
function bulk_user_admin_get_email_domain_stats() {
	$db = elgg()->db;
	$q = "SELECT value, substring_index(value, '@', -1) as domain, count(*) as count
		FROM {$db->prefix}metadata md
		JOIN {$db->prefix}entities e ON md.entity_guid = e.guid
		WHERE md.name = 'email'
			AND e.type = 'user'
			AND e.enabled = 'yes'
		group by domain order by count desc, domain asc;";

	return $db->getData($q);
}

function bulk_user_admin_get_sql_where_not_enqueued() {
	$db = elgg()->db;
	$name = \BulkUserAdmin\DeleteService::PENDING_DELETE_MD;
	$value = (int) true;

	return new \Elgg\Database\Clauses\WhereClause("NOT EXISTS (
			SELECT 1 FROM {$db->prefix}metadata md
			WHERE md.entity_guid = e.guid
				AND md.name = '{$name}'
				AND md.value = '{$value}')"
	);
}

/**
 * Get users with a few more options
 *
 * domain => Match the last part of the email address
 * only_banned => Only return banned users
 * enqueued => include|exclude|only users enqueued to be deleted (default = exclude, other values = doesn't matter)
 *
 * @param array $sent Options
 */
function bulk_user_admin_get_users(array $sent) {
	$defaults = [
		'type' => 'user',
		'domain' => false,
		'only_banned' => false,
		'enqueued' => 'exclude'
	];

	$options = array_merge($defaults, $sent);

	if (!is_array($options['wheres'])) {
		$options['wheres'] = [];
	}

	if (!is_array($options['joins'])) {
		$options['joins'] = [];
	}

	if ($options['domain']) {
		$options['joins'][]= new \Elgg\Database\Clauses\JoinClause('metadata', 'ue_dom', function(\Elgg\Database\QueryBuilder $qb, $joined_alias, $main_alias) {
			return $qb->compare("$joined_alias.entity_guid", '=', "$main_alias.guid");
		});
		$options['wheres'][] = new \Elgg\Database\Clauses\WhereClause("ue_dom.name = 'email' AND ue_dom.value LIKE '%@%{$options['domain']}'");
	}

	if ($options['only_banned']) {
		$options['joins'][]= new \Elgg\Database\Clauses\JoinClause('metadata', 'ue_ban', function(\Elgg\Database\QueryBuilder $qb, $joined_alias, $main_alias) {
			return $qb->compare("$joined_alias.entity_guid", '=', "$main_alias.guid");
		});
		$options['wheres'][] = new \Elgg\Database\Clauses\WhereClause("ue_ban.name = 'banned' AND ue_ban.value = 'yes'");
	}

	switch ($options['enqueued']) {
		case 'include':
			// no-op
			break;

		case 'only':
			$options['metadata_name'] = \BulkUserAdmin\DeleteService::PENDING_DELETE_MD;
			break;

		case 'exclude':
		default:
			$options['wheres'][] = bulk_user_admin_get_sql_where_not_enqueued();
			break;
	}

	return elgg_get_entities($options);
}
