<?php
/**
 * Form to delete users
 */

$users = elgg_extract('users', $vars);
$domain = elgg_extract('domain', $vars);
$only_banned = elgg_extract('banned', $vars);
$include_enqueued = elgg_extract('include_enqueued', $vars);

// profile fields
$fields = elgg_get_config('profile_fields');

$rows = [];

foreach ($users as $user) {

	$row = [];

	$checkbox = elgg_format_element('label', ['for' => "elgg-user-$user->guid"], elgg_view_field([
		'#type' => 'checkbox',
		'name' => 'bulk_user_admin_guids[]',
		'value' => $user->guid,
		'default' => false,
		'id' => 'elgg-user-' . $user->guid,
	]));
	$row[] = elgg_format_element('td', [], $checkbox);

	$user_icon = elgg_view_entity_icon($user, 'tiny', []);
	$user_icon = elgg_format_element('label', ['for' => "elgg-user-$user->guid"], $user_icon);
	$row[] = elgg_format_element('td', [], $user_icon);

	foreach (['time_created', 'last_login', 'last_action'] as $ts_name) {
		$ts = $user->$ts_name;
		if ($ts) {
			${$ts_name} = elgg_view_friendly_time($ts);
		} else {
			${$ts_name} = elgg_echo('bulk_user_admin:notavailable');
		}
	}

	$object_count = elgg_get_entities([
		'owner_guid' => $user->guid,
		'count' => true,
	]);
	$object_count = elgg_echo('bulk_user_admin:objectcounts') . $object_count;

	$annotation_count = elgg_get_annotations([
		'owner_guid' => $user->guid,
		'count' => true,
	]);
	$annotation_count = elgg_echo('bulk_user_admin:annotationscounts') . $annotation_count;

	$metadata_count = elgg_get_metadata([
		'owner_guid' => $user->guid,
		'count' => true,
	]);
	$metadata_count = elgg_echo('bulk_user_admin:metadatacounts') . $metadata_count;

	$tr_class = '';

	$banned = '';
	if ($user->isBanned()) {
		$tr_class .= 'bulk-user-admin-banned';
		$banned = '<br />' . elgg_echo('bulk_user_admin:banned') . $user->ban_reason;
	}

	$enqueued = '';
	if ($user->bulk_user_admin_delete_queued) {
		$tr_class .= ' bulk-user-admin-enqueued';
		$enqueued = "<br>" . elgg_echo('bulk_user_admin:enqueued');
	}

	$profile_field_tmp = [];

	foreach (array_keys($fields) as $md_name) {
		$value = $user->$md_name;

		if ($value) {
			$value_short = elgg_get_excerpt($value, 100);

			$profile_field_tmp[] = elgg_echo('profile:' . $md_name) . ': '
					. '<acronym title="' . strip_tags(htmlentities($value)) . '">'
					. $value_short . '</acronym>';
		}
	}

	$profile_fields = implode("<br />", $profile_field_tmp);
	if ($profile_fields) {
		$profile_fields = "<br />$profile_fields";
	}

	$row[] = elgg_format_element('td', [], elgg_format_element('label', ['for' => "elgg-user-$user->guid"], $user->name . " (" . $user->username . ", " . $user->guid . ")" . $enqueued . $banned . $profile_fields));

	$email = '';
	if ($user->email) {
		list($email_username, $email_domain) = explode('@', $user->email);
		$href = elgg_http_add_url_query_elements(elgg_normalize_url('/admin/users/bulk_user_admin'), [
			'domain' => $email_domain,
			'banned' => $only_banned,
			'include_enqueued' => $include_enqueued,
		]);
		$email = $email_username . '@' . elgg_view('output/url', [
			'text' => $email_domain,
			'href' => $href,
			'class' => 'bulk-user-admin-email-domain',
			'is_trusted' => true,
		]);
	}
	$row[] = elgg_format_element('td', [], $email);
// 	$row[] = elgg_format_element('td', [], elgg_format_element('label', ['for' => "elgg-user-$user->guid"], $time_created . "<br>" . $last_login));
// 	$row[] = elgg_format_element('td', [], elgg_format_element('label', ['for' => "elgg-user-$user->guid"], $last_action));
	$row[] = elgg_format_element('td', [], elgg_format_element('label', ['for' => "elgg-user-$user->guid"], $object_count . "<br>" . $annotation_count . "<br>" . $metadata_count));

	$rows[] = elgg_format_element('tr', ['class' => $tr_class], implode('', $row));
}

$header_row = [
	elgg_format_element('th', [], elgg_view_field(['#type' => 'checkbox', 'id' => 'checkAll'])),
	elgg_format_element('th', [], elgg_echo('bulk_user_admin:usericon')),
	elgg_format_element('th', [], elgg_echo('bulk_user_admin:userinfo') . "<br>" . elgg_echo('bulk_user_admin:profileinfo')),
	elgg_format_element('th', [], elgg_echo('bulk_user_admin:email')),
// 	elgg_format_element('th', [], elgg_echo('bulk_user_admin:timecreated') . "<br>" . elgg_echo('bulk_user_admin:lastlogin')),
// 	elgg_format_element('th', [], elgg_echo('bulk_user_admin:lastaction')),
	elgg_format_element('th', [], elgg_echo('bulk_user_admin:contentcounts')),
];
$header = elgg_format_element('tr', [], implode('', $header_row));

$table_content = elgg_format_element('thead', [], $header);
$table_content .= elgg_format_element('tbody', [], implode('', $rows));

echo elgg_format_element('table', ['class' => 'elgg-table bulk-user-admin-users'], $table_content);

if ($domain) {
	echo elgg_view_field([
		'#type' => 'hidden',
		'name' => 'domain',
		'value' => $domain,
	]);
}

if ($only_banned) {
	echo elgg_view_field([
		'#type' => 'hidden',
		'name' => 'banned',
		'value' => $only_banned,
	]);
}

if ($include_enqueued) {
	echo elgg_view_field([
		'#type' => 'hidden',
		'name' => 'include_enqueued',
		'value' => $include_enqueued,
	]);
}

echo elgg_view_field([
	'#type' => 'submit',
	'value' => elgg_echo('bulk_user_admin:delete:checked'),
	'confirm' => elgg_echo('bulk_user_admin:delete:checked?'),
	'class' => 'mtm',
]);
